@@ -3,4 +3,6 @@
 #![allow(non_camel_case_types)]
 #![allow(non_snake_case)]
 #![allow(improper_ctypes)]
+#![allow(clippy::redundant_static_lifetimes)]
+#![allow(clippy::upper_case_acronyms)]
 include!("../generated/bigwig.rs");
